@@ -1,3 +1,4 @@
+# PYTHON_ARGCOMPLETE_OK
 from __future__ import annotations
 
 import contextlib
@@ -5,10 +6,12 @@ import sys
 import time
 from argparse import ArgumentParser
 
-from gpustack_runtime import deployer, detector
+import argcomplete
 
+from . import deployer, detector
 from ._version import commit_id, version
 from .cmds import (
+    CopyImagesSubCommand,
     CreateRunnerWorkloadSubCommand,
     CreateWorkloadSubCommand,
     DeleteWorkloadsSubCommand,
@@ -16,8 +19,10 @@ from .cmds import (
     DetectDevicesSubCommand,
     ExecWorkloadSubCommand,
     GetWorkloadSubCommand,
+    ListImagesSubCommand,
     ListWorkloadsSubCommand,
     LogsWorkloadSubCommand,
+    SaveImagesSubCommand,
 )
 from .logging import setup_logging
 
@@ -33,18 +38,18 @@ def main():
         "--version",
         action="version",
         version=f"%(prog)s {version}({commit_id})",
-        help="show the version and exit",
+        help="Show the version and exit",
     )
     parser.add_argument(
         "--profile",
         action="store_true",
-        help="display available behaviors",
+        help="Display available behaviors",
     )
     parser.add_argument(
         "--watch",
         "-w",
         type=int,
-        help="continuously display available behaviors (used with --profile) in intervals of N seconds",
+        help="Continuously display available behaviors (used with --profile) in intervals of N seconds",
         default=0,
     )
 
@@ -61,6 +66,12 @@ def main():
     LogsWorkloadSubCommand.register(subcommand_parser)
     ExecWorkloadSubCommand.register(subcommand_parser)
     DetectDevicesSubCommand.register(subcommand_parser)
+    ListImagesSubCommand.register(subcommand_parser)
+    SaveImagesSubCommand.register(subcommand_parser)
+    CopyImagesSubCommand.register(subcommand_parser)
+
+    # Autocomplete
+    argcomplete.autocomplete(parser)
 
     # Parse
     args = parser.parse_args()
@@ -73,7 +84,10 @@ def main():
 
     # Run
     service = args.func(args)
-    service.run()
+    try:
+        service.run()
+    except KeyboardInterrupt:
+        print("\033[2J\033[H", end="")
 
 
 def profile(watch: int):
