@@ -11,8 +11,17 @@ from .deployer import (
     LogsWorkloadSubCommand,
 )
 from .detector import DetectDevicesSubCommand
+from .images import (
+    CopyImagesSubCommand,
+    ListImagesSubCommand,
+    PlatformedImage,
+    SaveImagesSubCommand,
+    append_images,
+    list_images,
+)
 
 __all__ = [
+    "CopyImagesSubCommand",
     "CreateRunnerWorkloadSubCommand",
     "CreateWorkloadSubCommand",
     "DeleteWorkloadSubCommand",
@@ -20,6 +29,11 @@ __all__ = [
     "DetectDevicesSubCommand",
     "ExecWorkloadSubCommand",
     "GetWorkloadSubCommand",
+    "ListImagesSubCommand",
     "ListWorkloadsSubCommand",
     "LogsWorkloadSubCommand",
+    "PlatformedImage",
+    "SaveImagesSubCommand",
+    "append_images",
+    "list_images",
 ]
