@@ -98,71 +98,71 @@ class CreateRunnerWorkloadSubCommand(SubCommand):
     def register(parser: _SubParsersAction):
         deploy_parser = parser.add_parser(
             "create-runner",
-            help="create a runner workload deployment",
+            help="Create a runner workload deployment",
         )
 
         deploy_parser.add_argument(
             "--backend",
             type=str,
-            help="backend to use (default: detect from current environment)",
+            help="Backend to use (default: detect from current environment)",
             choices=supported_backends(),
         )
 
         deploy_parser.add_argument(
             "--device",
             type=str,
-            help="device to use, multiple devices join by comma (default: all devices)",
+            help="Device to use, multiple devices join by comma (default: all devices)",
             default="all",
         )
 
         deploy_parser.add_argument(
             "--port",
             type=int,
-            help="port to expose",
+            help="Port to expose",
         )
 
         deploy_parser.add_argument(
             "--host-network",
             action="store_true",
-            help="use host network (default: False)",
+            help="Use host network (default: False)",
             default=False,
         )
 
         deploy_parser.add_argument(
             "--check",
             action="store_true",
-            help="enable health check, needs --port (default: False)",
+            help="Enable health check, needs --port (default: False)",
             default=False,
         )
 
         deploy_parser.add_argument(
             "--namespace",
             type=str,
-            help="namespace of the runner",
+            help="Namespace of the runner",
         )
 
         deploy_parser.add_argument(
             "service",
             type=str,
-            help="service of the runner",
+            help="Service of the runner",
         )
 
         deploy_parser.add_argument(
             "version",
             type=str,
-            help="version of the runner",
+            help="Version of the runner",
         )
 
         deploy_parser.add_argument(
             "volume",
             type=str,
-            help="volume to mount",
+            help="Volume to mount",
         )
 
         deploy_parser.add_argument(
             "extra_args",
             nargs=REMAINDER,
-            help="extra arguments for the runner",
+            help="Extra arguments for the runner",
         )
 
         deploy_parser.set_defaults(func=CreateRunnerWorkloadSubCommand)
@@ -262,34 +262,31 @@ class CreateRunnerWorkloadSubCommand(SubCommand):
         create_workload(plan)
         print(f"Created workload '{self.name}'.")
 
-        try:
-            while True:
-                st = get_workload(
-                    name=self.name,
-                    namespace=self.namespace,
-                )
-                if st and st.state not in (
-                    WorkloadStatusStateEnum.PENDING,
-                    WorkloadStatusStateEnum.INITIALIZING,
-                ):
-                    break
-                time.sleep(1)
+        while True:
+            st = get_workload(
+                name=self.name,
+                namespace=self.namespace,
+            )
+            if st and st.state not in (
+                WorkloadStatusStateEnum.PENDING,
+                WorkloadStatusStateEnum.INITIALIZING,
+            ):
+                break
+            time.sleep(1)
 
-            print("\033[2J\033[H", end="")
+        print("\033[2J\033[H", end="")
 
-            async def stream_logs():
-                logs_result = await async_logs_workload(
-                    name=self.name,
-                    namespace=self.namespace,
-                    tail=-1,
-                    follow=True,
-                )
-                async for line in logs_result:
-                    print(line.decode("utf-8").rstrip())
+        async def stream_logs():
+            logs_result = await async_logs_workload(
+                name=self.name,
+                namespace=self.namespace,
+                tail=-1,
+                follow=True,
+            )
+            async for line in logs_result:
+                print(line.decode("utf-8").rstrip())
 
-            asyncio.run(stream_logs())
-        except KeyboardInterrupt:
-            print("\033[2J\033[H", end="")
+        asyncio.run(stream_logs())
 
 
 class CreateWorkloadSubCommand(SubCommand):
@@ -312,71 +309,71 @@ class CreateWorkloadSubCommand(SubCommand):
     def register(parser: _SubParsersAction):
         deploy_parser = parser.add_parser(
             "create",
-            help="create a workload deployment",
+            help="Create a workload deployment",
         )
 
         deploy_parser.add_argument(
             "--backend",
             type=str,
-            help="backend to use (default: detect from current environment)",
+            help="Backend to use (default: detect from current environment)",
             choices=supported_backends(),
         )
 
         deploy_parser.add_argument(
             "--device",
             type=str,
-            help="device to use, multiple devices join by comma (default: all devices)",
+            help="Device to use, multiple devices join by comma (default: all devices)",
             default="all",
         )
 
         deploy_parser.add_argument(
             "--port",
             type=int,
-            help="port to expose",
+            help="Port to expose",
         )
 
         deploy_parser.add_argument(
             "--host-network",
             action="store_true",
-            help="use host network (default: False)",
+            help="Use host network (default: False)",
             default=False,
         )
 
         deploy_parser.add_argument(
             "--check",
             action="store_true",
-            help="enable health check, needs --port (default: False)",
+            help="Enable health check, needs --port (default: False)",
             default=False,
         )
 
         deploy_parser.add_argument(
             "--namespace",
             type=str,
-            help="namespace of the workload",
+            help="Namespace of the workload",
         )
 
         deploy_parser.add_argument(
             "name",
             type=str,
-            help="name of the workload",
+            help="Name of the workload",
         )
 
         deploy_parser.add_argument(
             "image",
             type=str,
-            help="image to deploy (should be a valid Docker image)",
+            help="Image to deploy (should be a valid Docker image)",
         )
 
         deploy_parser.add_argument(
             "volume",
             type=str,
-            help="volume to mount",
+            help="Volume to mount",
         )
 
         deploy_parser.add_argument(
             "extra_args",
             nargs=REMAINDER,
-            help="extra arguments for the workload",
+            help="Extra arguments for the workload",
         )
 
         deploy_parser.set_defaults(func=CreateWorkloadSubCommand)
@@ -475,34 +472,31 @@ class CreateWorkloadSubCommand(SubCommand):
         create_workload(plan)
         print(f"Created workload '{self.name}'.")
 
-        try:
-            while True:
-                st = get_workload(
-                    name=self.name,
-                    namespace=self.namespace,
-                )
-                if st and st.state not in (
-                    WorkloadStatusStateEnum.PENDING,
-                    WorkloadStatusStateEnum.INITIALIZING,
-                ):
-                    break
-                time.sleep(1)
+        while True:
+            st = get_workload(
+                name=self.name,
+                namespace=self.namespace,
+            )
+            if st and st.state not in (
+                WorkloadStatusStateEnum.PENDING,
+                WorkloadStatusStateEnum.INITIALIZING,
+            ):
+                break
+            time.sleep(1)
 
-            print("\033[2J\033[H", end="")
+        print("\033[2J\033[H", end="")
 
-            async def stream_logs():
-                logs_result = await async_logs_workload(
-                    name=self.name,
-                    namespace=self.namespace,
-                    tail=-1,
-                    follow=True,
-                )
-                async for line in logs_result:
-                    print(line.decode("utf-8").rstrip())
+        async def stream_logs():
+            logs_result = await async_logs_workload(
+                name=self.name,
+                namespace=self.namespace,
+                tail=-1,
+                follow=True,
+            )
+            async for line in logs_result:
+                print(line.decode("utf-8").rstrip())
 
-            asyncio.run(stream_logs())
-        except KeyboardInterrupt:
-            print("\033[2J\033[H", end="")
+        asyncio.run(stream_logs())
 
 
 class DeleteWorkloadSubCommand(SubCommand):
@@ -517,19 +511,19 @@ class DeleteWorkloadSubCommand(SubCommand):
     def register(parser: _SubParsersAction):
         delete_parser = parser.add_parser(
             "delete",
-            help="delete a workload deployment",
+            help="Delete a workload deployment",
         )
 
         delete_parser.add_argument(
             "--namespace",
             type=str,
-            help="namespace of the workload",
+            help="Namespace of the workload",
         )
 
         delete_parser.add_argument(
             "name",
             type=str,
-            help="name of the workload",
+            help="Name of the workload",
         )
 
         delete_parser.set_defaults(func=DeleteWorkloadSubCommand)
@@ -543,17 +537,14 @@ class DeleteWorkloadSubCommand(SubCommand):
             raise ValueError(msg)
 
     def run(self):
-        try:
-            st = delete_workload(
-                name=self.name,
-                namespace=self.namespace,
-            )
-            if st:
-                print(f"Deleted workload '{self.name}'.")
-            else:
-                print(f"Workload '{self.name}' not found.")
-        except KeyboardInterrupt:
-            pass
+        st = delete_workload(
+            name=self.name,
+            namespace=self.namespace,
+        )
+        if st:
+            print(f"Deleted workload '{self.name}'.")
+        else:
+            print(f"Workload '{self.name}' not found.")
 
 
 class DeleteWorkloadsSubCommand(SubCommand):
@@ -565,20 +556,20 @@ class DeleteWorkloadsSubCommand(SubCommand):
     def register(parser: _SubParsersAction):
         delete_parser = parser.add_parser(
             "delete-all",
-            help="delete all workload deployments",
+            help="Delete all workload deployments",
         )
 
         delete_parser.add_argument(
             "--namespace",
             type=str,
-            help="namespace of the workload",
+            help="Namespace of the workload",
         )
 
         delete_parser.add_argument(
             "--labels",
             type=lambda s: dict(item.split("=") for item in s.split(",")),
             required=False,
-            help="filter workloads by labels (key=value pairs separated by commas)",
+            help="Filter workloads by labels (key=value pairs separated by commas)",
         )
 
         delete_parser.set_defaults(func=DeleteWorkloadsSubCommand)
@@ -588,21 +579,18 @@ class DeleteWorkloadsSubCommand(SubCommand):
         self.labels = args.labels
 
     def run(self):
-        try:
-            sts: list[WorkloadStatus] = list_workloads(
-                namespace=self.namespace,
-                labels=self.labels,
+        sts: list[WorkloadStatus] = list_workloads(
+            namespace=self.namespace,
+            labels=self.labels,
+        )
+        for st in sts:
+            delete_workload(
+                name=st.name,
+                namespace=st.namespace,
             )
-            for st in sts:
-                delete_workload(
-                    name=st.name,
-                    namespace=st.namespace,
-                )
-                print(f"Deleted workload '{st.name}'.")
-            if not sts:
-                print("No workloads found.")
-        except KeyboardInterrupt:
-            pass
+            print(f"Deleted workload '{st.name}'.")
+        if not sts:
+            print("No workloads found.")
 
 
 class GetWorkloadSubCommand(SubCommand):
@@ -619,7 +607,7 @@ class GetWorkloadSubCommand(SubCommand):
     def register(parser: _SubParsersAction):
         get_parser = parser.add_parser(
             "get",
-            help="get the status of a workload deployment",
+            help="Get the status of a workload deployment",
         )
 
         get_parser.add_argument(
@@ -627,27 +615,27 @@ class GetWorkloadSubCommand(SubCommand):
             type=str,
             choices=["table", "json"],
             default="table",
-            help="output format",
+            help="Putput format",
         )
 
         get_parser.add_argument(
             "--watch",
             "-w",
             type=int,
-            help="continuously watch for the workload in intervals of N seconds",
+            help="Continuously watch for the workload in intervals of N seconds",
             default=0,
         )
 
         get_parser.add_argument(
             "--namespace",
             type=str,
-            help="namespace of the workload",
+            help="Namespace of the workload",
         )
 
         get_parser.add_argument(
             "name",
             type=str,
-            help="name of the workload",
+            help="Name of the workload",
         )
 
         get_parser.set_defaults(func=GetWorkloadSubCommand)
@@ -663,25 +651,22 @@ class GetWorkloadSubCommand(SubCommand):
             raise ValueError(msg)
 
     def run(self):
-        try:
-            while True:
-                workload = get_workload(self.name, self.namespace)
-                if not workload:
-                    print(f"Workload '{self.name}' not found.")
-                    return
+        while True:
+            workload = get_workload(self.name, self.namespace)
+            if not workload:
+                print(f"Workload '{self.name}' not found.")
+                return
 
-                sts: list[WorkloadStatus] = [workload]
-                print("\033[2J\033[H", end="")
-                match self.format.lower():
-                    case "json":
-                        print(format_workloads_json(sts))
-                    case _:
-                        print(format_workloads_table(sts))
-                if not self.watch:
-                    break
-                time.sleep(self.watch)
-        except KeyboardInterrupt:
+            sts: list[WorkloadStatus] = [workload]
             print("\033[2J\033[H", end="")
+            match self.format.lower():
+                case "json":
+                    print(format_workloads_json(sts))
+                case _:
+                    print(format_workloads_table(sts))
+            if not self.watch:
+                break
+            time.sleep(self.watch)
 
 
 class ListWorkloadsSubCommand(SubCommand):
@@ -698,20 +683,20 @@ class ListWorkloadsSubCommand(SubCommand):
     def register(parser: _SubParsersAction):
         list_parser = parser.add_parser(
             "list",
-            help="list all workload deployments",
+            help="List all workload deployments",
         )
 
         list_parser.add_argument(
             "--namespace",
             type=str,
-            help="namespace of the workloads",
+            help="Namespace of the workloads",
         )
 
         list_parser.add_argument(
             "--labels",
             type=lambda s: dict(item.split("=") for item in s.split(",")),
             required=False,
-            help="filter workloads by labels (key=value pairs separated by commas)",
+            help="Filter workloads by labels (key=value pairs separated by commas)",
         )
 
         list_parser.add_argument(
@@ -719,14 +704,14 @@ class ListWorkloadsSubCommand(SubCommand):
             type=str,
             choices=["table", "json"],
             default="table",
-            help="output format",
+            help="Output format",
         )
 
         list_parser.add_argument(
             "--watch",
             "-w",
             type=int,
-            help="continuously watch for workloads in intervals of N seconds",
+            help="Continuously watch for workloads in intervals of N seconds",
         )
 
         list_parser.set_defaults(func=ListWorkloadsSubCommand)
@@ -738,23 +723,20 @@ class ListWorkloadsSubCommand(SubCommand):
         self.watch = args.watch
 
     def run(self):
-        try:
-            while True:
-                sts: list[WorkloadStatus] = list_workloads(
-                    namespace=self.namespace,
-                    labels=self.labels,
-                )
-                print("\033[2J\033[H", end="")
-                match self.format.lower():
-                    case "json":
-                        print(format_workloads_json(sts))
-                    case _:
-                        print(format_workloads_table(sts))
-                if not self.watch:
-                    break
-                time.sleep(self.watch)
-        except KeyboardInterrupt:
+        while True:
+            sts: list[WorkloadStatus] = list_workloads(
+                namespace=self.namespace,
+                labels=self.labels,
+            )
             print("\033[2J\033[H", end="")
+            match self.format.lower():
+                case "json":
+                    print(format_workloads_json(sts))
+                case _:
+                    print(format_workloads_table(sts))
+            if not self.watch:
+                break
+            time.sleep(self.watch)
 
 
 class LogsWorkloadSubCommand(SubCommand):
@@ -771,13 +753,13 @@ class LogsWorkloadSubCommand(SubCommand):
     def register(parser: _SubParsersAction):
         logs_parser = parser.add_parser(
             "logs",
-            help="get the logs of a workload deployment",
+            help="Get the logs of a workload deployment",
         )
 
         logs_parser.add_argument(
             "--tail",
             type=int,
-            help="number of lines to show from the end of the logs (default: -1)",
+            help="Number of lines to show from the end of the logs (default: -1)",
             default=-1,
         )
 
@@ -785,19 +767,19 @@ class LogsWorkloadSubCommand(SubCommand):
             "--follow",
             "-f",
             action="store_true",
-            help="follow the logs in real-time",
+            help="Follow the logs in real-time",
         )
 
         logs_parser.add_argument(
             "--namespace",
             type=str,
-            help="namespace of the workload",
+            help="Namespace of the workload",
         )
 
         logs_parser.add_argument(
             "name",
             type=str,
-            help="name of the workload",
+            help="Name of the workload",
         )
 
         logs_parser.set_defaults(func=LogsWorkloadSubCommand)
@@ -813,27 +795,24 @@ class LogsWorkloadSubCommand(SubCommand):
             raise ValueError(msg)
 
     def run(self):
-        try:
-            print("\033[2J\033[H", end="")
+        print("\033[2J\033[H", end="")
 
-            async def stream_logs():
-                logs_result = await async_logs_workload(
-                    name=self.name,
-                    namespace=self.namespace,
-                    tail=self.tail,
-                    follow=self.follow,
-                )
-                if self.follow:
-                    async for line in logs_result:
-                        print(line.decode("utf-8").rstrip())
-                elif isinstance(logs_result, str):
-                    print(logs_result.rstrip())
-                else:
-                    print(logs_result.decode("utf-8").rstrip())
+        async def stream_logs():
+            logs_result = await async_logs_workload(
+                name=self.name,
+                namespace=self.namespace,
+                tail=self.tail,
+                follow=self.follow,
+            )
+            if self.follow:
+                async for line in logs_result:
+                    print(line.decode("utf-8").rstrip())
+            elif isinstance(logs_result, str):
+                print(logs_result.rstrip())
+            else:
+                print(logs_result.decode("utf-8").rstrip())
 
-            asyncio.run(stream_logs())
-        except KeyboardInterrupt:
-            print("\033[2J\033[H", end="")
+        asyncio.run(stream_logs())
 
 
 class ExecWorkloadSubCommand(SubCommand):
@@ -850,32 +829,32 @@ class ExecWorkloadSubCommand(SubCommand):
     def register(parser: _SubParsersAction):
         exec_parser = parser.add_parser(
             "exec",
-            help="execute a command in a workload deployment",
+            help="Execute a command in a workload deployment",
         )
 
         exec_parser.add_argument(
             "--interactive",
             "-i",
             action="store_true",
-            help="interactive mode",
+            help="Interactive mode",
         )
 
         exec_parser.add_argument(
             "--namespace",
             type=str,
-            help="namespace of the workload",
+            help="Namespace of the workload",
         )
 
         exec_parser.add_argument(
             "name",
             type=str,
-            help="name of the workload",
+            help="Name of the workload",
         )
 
         exec_parser.add_argument(
             "command",
             nargs=REMAINDER,
-            help="command to execute in the workload",
+            help="Command to execute in the workload",
         )
 
         exec_parser.set_defaults(func=ExecWorkloadSubCommand)
@@ -901,52 +880,49 @@ class ExecWorkloadSubCommand(SubCommand):
             )
             sys.exit(1)
 
-        try:
-            print("\033[2J\033[H", end="")
-            exec_result = exec_workload(
-                name=self.name,
-                namespace=self.namespace,
-                detach=not self.interactive,
-                command=self.command,
-            )
+        print("\033[2J\033[H", end="")
+        exec_result = exec_workload(
+            name=self.name,
+            namespace=self.namespace,
+            detach=not self.interactive,
+            command=self.command,
+        )
 
-            # Non-interactive mode: print output and exit with the command's exit code
+        # Non-interactive mode: print output and exit with the command's exit code
 
-            if not self.interactive:
-                if isinstance(exec_result, bytes):
-                    print(exec_result.decode("utf-8").rstrip())
-                else:
-                    print(exec_result)
-                return
+        if not self.interactive:
+            if isinstance(exec_result, bytes):
+                print(exec_result.decode("utf-8").rstrip())
+            else:
+                print(exec_result)
+            return
 
-            # Interactive mode: use dockerpty to attach to the exec session
+        # Interactive mode: use dockerpty to attach to the exec session
 
-            class ExecOperation(pty.Operation):
-                def __init__(self, sock):
-                    self.stdin = sys.stdin
-                    self.stdout = sys.stdout
-                    self.sock = io.Stream(sock)
+        class ExecOperation(pty.Operation):
+            def __init__(self, sock):
+                self.stdin = sys.stdin
+                self.stdout = sys.stdout
+                self.sock = io.Stream(sock)
 
-                def israw(self, **_):
-                    return self.stdout.isatty()
+            def israw(self, **_):
+                return self.stdout.isatty()
 
-                def start(self, **_):
-                    sock = self.sockets()
-                    return [
-                        io.Pump(io.Stream(self.stdin), sock, wait_for_output=False),
-                        io.Pump(sock, io.Stream(self.stdout), propagate_close=False),
-                    ]
+            def start(self, **_):
+                sock = self.sockets()
+                return [
+                    io.Pump(io.Stream(self.stdin), sock, wait_for_output=False),
+                    io.Pump(sock, io.Stream(self.stdout), propagate_close=False),
+                ]
 
-                def resize(self, height, width, **_):
-                    pass
+            def resize(self, height, width, **_):
+                pass
 
-                def sockets(self):
-                    return self.sock
+            def sockets(self):
+                return self.sock
 
-            exec_op = ExecOperation(exec_result)
-            pty.PseudoTerminal(None, exec_op).start()
-        except KeyboardInterrupt:
-            print("\033[2J\033[H", end="")
+        exec_op = ExecOperation(exec_result)
+        pty.PseudoTerminal(None, exec_op).start()
 
 
 def format_workloads_json(sts: list[WorkloadStatus]) -> str:
