@@ -42,6 +42,7 @@ from .__types__ import (
     WorkloadStatusOperation,
     WorkloadStatusStateEnum,
 )
+from .__utils__ import _MiB, bytes_to_human_readable
 
 if TYPE_CHECKING:
     from collections.abc import Callable, Generator
@@ -437,7 +438,7 @@ class DockerDeployer(Deployer):
                 )
                 logger.debug("Created volume %s", n)
         except docker.errors.APIError as e:
-            msg = "Failed to create ephemeral volumes"
+            msg = f"Failed to create ephemeral volumes{_detail_api_call_error(e)}"
             raise OperationError(msg) from e
 
         return ephemeral_volume_name_mapping
@@ -454,9 +455,12 @@ class DockerDeployer(Deployer):
                 stream=True,
             )
 
+            progress_threshold = 1
             progress: int = 0
+            progress_current: int = 0
             layers: dict[str, int] = {}
             layer_progress: dict[str, int] = {}
+            layer_progress_current: dict[str, int] = {}
             is_raw = sys.stdout.isatty() and logger.isEnabledFor(logging.DEBUG)
             for line in pull_log:
                 line_str = (
@@ -476,6 +480,7 @@ class DockerDeployer(Deployer):
                     if log_id not in layers:
                         layers[log_id] = len(layers)
                         layer_progress[log_id] = 0
+                        layer_progress_current[log_id] = 0
                     if is_raw:
                         print("\033[E", end="")
                         print(f"\033[{layers[log_id] + 1};0H", end="")
@@ -488,15 +493,29 @@ class DockerDeployer(Deployer):
                             p_t = log.get("progressDetail", {}).get("total")
                             if p_c is not None and p_t is not None:
                                 layer_progress[log_id] = int(p_c * 100 // p_t)
-                            p_diff = (
-                                sum(layer_progress.values())
-                                * 100
-                                // (len(layer_progress) * 100)
-                                - progress
-                            )
-                            if p_diff >= 10:
-                                progress += 10
-                                logger.info(f"Pulling image {image}: {progress}%")
+                                p_diff = (
+                                    sum(layer_progress.values())
+                                    * 100
+                                    // (len(layer_progress) * 100)
+                                    - progress
+                                )
+                                if p_diff >= progress_threshold:
+                                    progress += progress_threshold
+                                    progress_threshold = min(5, progress_threshold + 1)
+                                    logger.info(f"Pulling image {image}: {progress}%")
+                            elif p_c is not None:
+                                layer_progress_current[log_id] = p_c
+                                p_c_total = sum(layer_progress_current.values())
+                                p_diff = p_c_total - progress_current
+                                if p_diff >= progress_threshold * _MiB:
+                                    progress_current = p_c_total
+                                    progress_threshold = min(
+                                        200,
+                                        progress_threshold + 2,
+                                    )
+                                    logger.info(
+                                        f"Pulling image {image}: {bytes_to_human_readable(p_c_total)}",
+                                    )
                     elif is_raw:
                         print(f"{log_id}: {log['status']}", flush=True)
 
@@ -506,7 +525,7 @@ class DockerDeployer(Deployer):
             msg = f"Failed to pull image {image}, invalid response"
             raise OperationError(msg) from e
         except docker.errors.APIError as e:
-            msg = f"Failed to pull image {image}"
+            msg = f"Failed to pull image {image}{_detail_api_call_error(e)}"
             raise OperationError(msg) from e
 
     def _get_image(
@@ -539,7 +558,7 @@ class DockerDeployer(Deployer):
             if policy == ContainerImagePullPolicyEnum.ALWAYS:
                 return self._pull_image(image)
         except docker.errors.APIError as e:
-            msg = f"Failed to get image {image}"
+            msg = f"Failed to get image {image}{_detail_api_call_error(e)}"
             raise OperationError(msg) from e
 
         try:
@@ -549,7 +568,7 @@ class DockerDeployer(Deployer):
                 raise
             return self._pull_image(image)
         except docker.errors.APIError as e:
-            msg = f"Failed to get image {image}"
+            msg = f"Failed to get image {image}{_detail_api_call_error(e)}"
             raise OperationError(msg) from e
 
     def _create_pause_container(
@@ -573,7 +592,7 @@ class DockerDeployer(Deployer):
         except docker.errors.NotFound:
             pass
         except docker.errors.APIError as e:
-            msg = f"Failed to confirm whether container {container_name} exists"
+            msg = f"Failed to confirm whether container {container_name} exists{_detail_api_call_error(e)}"
             raise OperationError(msg) from e
         else:
             # TODO(thxCode): check if the container matches the spec
@@ -606,8 +625,7 @@ class DockerDeployer(Deployer):
 
         if workload.host_ipc:
             create_options["ipc_mode"] = "host"
-
-        if not workload.host_ipc and workload.shm_size:
+        elif workload.shm_size:
             create_options["shm_size"] = workload.shm_size
 
         try:
@@ -617,7 +635,7 @@ class DockerDeployer(Deployer):
                 **create_options,
             )
         except docker.errors.APIError as e:
-            msg = f"Failed to create container {container_name}"
+            msg = f"Failed to create container {container_name}{_detail_api_call_error(e)}"
             raise OperationError(msg) from e
         else:
             return d_container
@@ -652,7 +670,7 @@ class DockerDeployer(Deployer):
         except docker.errors.NotFound:
             pass
         except docker.errors.APIError as e:
-            msg = f"Failed to confirm whether container {container_name} exists"
+            msg = f"Failed to confirm whether container {container_name} exists{_detail_api_call_error(e)}"
             raise OperationError(msg) from e
         else:
             # TODO(thxCode): check if the container matches the spec
@@ -681,7 +699,7 @@ class DockerDeployer(Deployer):
                 **create_options,
             )
         except docker.errors.APIError as e:
-            msg = f"Failed to create container {container_name}"
+            msg = f"Failed to create container {container_name}{_detail_api_call_error(e)}"
             raise OperationError(msg) from e
         else:
             return d_container
@@ -861,7 +879,7 @@ class DockerDeployer(Deployer):
             except docker.errors.NotFound:
                 pass
             except docker.errors.APIError as e:
-                msg = f"Failed to confirm whether container {container_name} exists"
+                msg = f"Failed to confirm whether container {container_name} exists{_detail_api_call_error(e)}"
                 raise OperationError(msg) from e
             else:
                 # TODO(thxCode): check if the container matches the spec
@@ -885,6 +903,9 @@ class DockerDeployer(Deployer):
                 },
             }
 
+            if not workload.host_ipc and workload.shm_size:
+                create_options["shm_size"] = workload.shm_size
+
             if workload.pid_shared:
                 create_options["pid_mode"] = pause_container_namespace
 
@@ -1049,7 +1070,7 @@ class DockerDeployer(Deployer):
                     **create_options,
                 )
             except docker.errors.APIError as e:
-                msg = f"Failed to create container {container_name}"
+                msg = f"Failed to create container {container_name}{_detail_api_call_error(e)}"
                 raise OperationError(msg) from e
             else:
                 if c.profile == ContainerProfileEnum.INIT:
@@ -1419,7 +1440,9 @@ class DockerDeployer(Deployer):
             if unhealthy_restart_container:
                 self._start_containers(unhealthy_restart_container)
         except docker.errors.APIError as e:
-            msg = f"Failed to create workload {workload.name}"
+            msg = (
+                f"Failed to create workload {workload.name}{_detail_api_call_error(e)}"
+            )
             raise OperationError(msg) from e
 
     @_supported
@@ -1462,7 +1485,7 @@ class DockerDeployer(Deployer):
                 **list_options,
             )
         except docker.errors.APIError as e:
-            msg = f"Failed to list containers for workload {name}"
+            msg = f"Failed to list containers for workload {name}{_detail_api_call_error(e)}"
             raise OperationError(msg) from e
 
         if not d_containers:
@@ -1511,7 +1534,7 @@ class DockerDeployer(Deployer):
                     force=True,
                 )
         except docker.errors.APIError as e:
-            msg = f"Failed to delete containers for workload {name}"
+            msg = f"Failed to delete containers for workload {name}{_detail_api_call_error(e)}"
             raise OperationError(msg) from e
 
         # Remove all ephemeral volumes with the workload label.
@@ -1532,7 +1555,7 @@ class DockerDeployer(Deployer):
                     force=True,
                 )
         except docker.errors.APIError as e:
-            msg = f"Failed to delete volumes for workload {name}"
+            msg = f"Failed to delete volumes for workload {name}{_detail_api_call_error(e)}"
             raise OperationError(msg) from e
 
         # Remove all ephemeral files for the workload.
@@ -1598,7 +1621,7 @@ class DockerDeployer(Deployer):
                 **list_options,
             )
         except docker.errors.APIError as e:
-            msg = "Failed to list workloads' containers"
+            msg = f"Failed to list workloads' containers{_detail_api_call_error(e)}"
             raise OperationError(msg) from e
 
         # Group containers by workload name,
@@ -1698,7 +1721,7 @@ class DockerDeployer(Deployer):
                 **logs_options,
             )
         except docker.errors.APIError as e:
-            msg = f"Failed to fetch logs for container {container.name} of workload {name}"
+            msg = f"Failed to fetch logs for container {container.name} of workload {name}{_detail_api_call_error(e)}"
             raise OperationError(msg) from e
         else:
             return output
@@ -1778,7 +1801,7 @@ class DockerDeployer(Deployer):
                 **exec_options,
             )
         except docker.errors.APIError as e:
-            msg = f"Failed to exec command in container {container.name} of workload {name}"
+            msg = f"Failed to exec command in container {container.name} of workload {name}{_detail_api_call_error(e)}"
             raise OperationError(msg) from e
         else:
             if not attach:
@@ -1826,3 +1849,30 @@ class DockerWorkloadExecStream(WorkloadExecStream):
         if self.closed:
             return
         self._sock.close()
+
+
+def _detail_api_call_error(err: docker.errors.APIError) -> str:
+    """
+    Explain a Docker API error in a concise way,
+    if the envs.GPUSTACK_RUNTIME_DEPLOY_API_CALL_ERROR_DETAIL is enabled.
+
+    Args:
+        err:
+            The Docker API error.
+
+    Returns:
+        A concise explanation of the error.
+
+    """
+    if not envs.GPUSTACK_RUNTIME_DEPLOY_API_CALL_ERROR_DETAIL:
+        return ""
+
+    msg = f": Docker {'Client' if err.is_client_error() else 'Server'} Error"
+    if err.explanation:
+        msg += f": {err.explanation}"
+    elif err.response.reason:
+        msg += f": {err.response.reason}"
+    else:
+        msg += f": status code {err.response.status_code}"
+
+    return msg
