@@ -430,7 +430,7 @@ class KubernetesDeployer(Deployer):
                         workload.namespace,
                     )
         except kubernetes.client.exceptions.ApiException as e:
-            msg = f"Failed to create configmap for workload {workload.name}"
+            msg = f"Failed to create configmap for workload {workload.name}{_detail_api_call_error(e)}"
             raise OperationError(msg) from e
 
         return ephemeral_filename_mapping
@@ -706,7 +706,7 @@ class KubernetesDeployer(Deployer):
                     workload.namespace,
                 )
         except kubernetes.client.exceptions.ApiException as e:
-            msg = f"Failed to create service for workload {workload.name}"
+            msg = f"Failed to create service for workload {workload.name}{_detail_api_call_error(e)}"
             raise OperationError(msg) from e
 
         return service
@@ -1029,7 +1029,7 @@ class KubernetesDeployer(Deployer):
                     workload.namespace,
                 )
         except kubernetes.client.exceptions.ApiException as e:
-            msg = f"Failed to create pod for workload {workload.name}"
+            msg = f"Failed to create pod for workload {workload.name}{_detail_api_call_error(e)}"
             raise OperationError(msg) from e
 
         return pod
@@ -1051,7 +1051,7 @@ class KubernetesDeployer(Deployer):
             try:
                 nodes = core_api.list_node(limit=1)
             except kubernetes.client.exceptions.ApiException as e:
-                msg = "Failed to get the default node name of the cluster"
+                msg = f"Failed to get the default node name of the cluster{_detail_api_call_error(e)}"
                 raise OperationError(msg) from e
             else:
                 if nodes.items:
@@ -1121,6 +1121,10 @@ class KubernetesDeployer(Deployer):
         )
         ## - Pod runtime class name
         mirrored_runtime_class_name: str = self_pod.spec.runtime_class_name or ""
+        ## - Pod image pull secrets
+        mirrored_image_pull_secrets: list[kubernetes.client.V1LocalObjectReference] = (
+            self_pod.spec.image_pull_secrets
+        )
         ## - Container envs
         mirrored_envs: list[kubernetes.client.V1EnvVar] = [
             # Filter out gpustack-internal envs and cross-namespace secret/envref envs.
@@ -1212,6 +1216,18 @@ class KubernetesDeployer(Deployer):
             if mirrored_runtime_class_name and not pod.spec.runtime_class_name:
                 pod.spec.runtime_class_name = mirrored_runtime_class_name
 
+            if mirrored_image_pull_secrets:
+                pod.spec.image_pull_secrets = pod.spec.image_pull_secrets or []
+                p_image_pull_secrets_names = {
+                    # Map existing image pull secret names.
+                    ips.name
+                    for ips in pod.spec.image_pull_secrets
+                }
+                for ips in mirrored_image_pull_secrets:
+                    if ips.name not in p_image_pull_secrets_names:
+                        pod.spec.image_pull_secrets.append(ips)
+                        p_image_pull_secrets_names.add(ips.name)
+
             if mirrored_envs:
                 for ci in pod.spec.containers:
                     c_env_names = {ei.name for ei in ci.env or []}
@@ -1221,15 +1237,16 @@ class KubernetesDeployer(Deployer):
 
             if mirrored_volume_mounts or mirrored_volume_devices:
                 for ci in pod.spec.containers:
+                    ci.volume_mounts = ci.volume_mounts or []
                     c_volume_mount_names = {
                         # Map existing volume mount names.
                         mi.name
-                        for mi in ci.volume_mounts or []
+                        for mi in ci.volume_mounts
                     }
                     c_volume_mount_paths = {
                         # Map existing volume mount paths.
                         mi.mount_path
-                        for mi in ci.volume_mounts or []
+                        for mi in ci.volume_mounts
                     }
                     # Append volume mounts if not exists.
                     for mi in mirrored_volume_mounts:
@@ -1237,40 +1254,39 @@ class KubernetesDeployer(Deployer):
                             mi.name not in c_volume_mount_names
                             and mi.mount_path not in c_volume_mount_paths
                         ):
-                            ci.volume_mounts = ci.volume_mounts or []
                             ci.volume_mounts.append(mi)
                             c_volume_mount_names.add(mi.name)
                             c_volume_mount_paths.add(mi.mount_path)
+                    ci.volume_devices = ci.volume_devices or []
                     # Append volume devices if not exists.
                     c_volume_device_names = {
                         # Map existing volume device names.
                         di.name
-                        for di in ci.volume_devices or []
+                        for di in ci.volume_devices
                     }
                     c_volume_device_paths = {
                         # Map existing volume device paths.
                         di.device_path
-                        for di in ci.volume_devices or []
+                        for di in ci.volume_devices
                     }
                     for di in mirrored_volume_devices:
                         if (
                             di.name not in c_volume_device_names
                             and di.device_path not in c_volume_device_paths
                         ):
-                            ci.volume_devices = ci.volume_devices or []
                             ci.volume_devices.append(di)
                             c_volume_device_names.add(di.name)
                             c_volume_device_paths.add(di.device_path)
 
             if mirrored_volumes:
+                pod.spec.volumes = pod.spec.volumes or []
                 p_volume_names = {
                     # Map existing volume names.
                     vi.name
-                    for vi in pod.spec.volumes or []
+                    for vi in pod.spec.volumes
                 }
                 for vi in mirrored_volumes:
                     if vi.name not in p_volume_names:
-                        pod.spec.volumes = pod.spec.volumes or []
                         pod.spec.volumes.append(vi)
                         p_volume_names.add(vi.name)
 
@@ -1367,7 +1383,7 @@ class KubernetesDeployer(Deployer):
                 **list_options,
             )
         except kubernetes.client.exceptions.ApiException as e:
-            msg = f"Failed to get deployment of workload {name}"
+            msg = f"Failed to get deployment of workload {name}{_detail_api_call_error(e)}"
             raise OperationError(msg) from e
 
         if len(k_pods.items) > 1:
@@ -1431,7 +1447,7 @@ class KubernetesDeployer(Deployer):
                 propagation_policy="Foreground",
             )
         except kubernetes.client.exceptions.ApiException as e:
-            msg = f"Failed to delete pod of workload {name}"
+            msg = f"Failed to delete pod of workload {name}{_detail_api_call_error(e)}"
             raise OperationError(msg) from e
 
         # Remove all Services with the workload label.
@@ -1442,7 +1458,7 @@ class KubernetesDeployer(Deployer):
                 propagation_policy="Foreground",
             )
         except kubernetes.client.exceptions.ApiException as e:
-            msg = f"Failed to delete service of workload {name}"
+            msg = f"Failed to delete service of workload {name}{_detail_api_call_error(e)}"
             raise OperationError(msg) from e
 
         # Remove all ConfigMaps with the workload label.
@@ -1453,7 +1469,7 @@ class KubernetesDeployer(Deployer):
                 propagation_policy="Foreground",
             )
         except kubernetes.client.exceptions.ApiException as e:
-            msg = f"Failed to delete configmap of workload {name}"
+            msg = f"Failed to delete configmap of workload {name}{_detail_api_call_error(e)}"
             raise OperationError(msg) from e
 
         return workload
@@ -1509,7 +1525,7 @@ class KubernetesDeployer(Deployer):
                 **list_options,
             )
         except kubernetes.client.exceptions.ApiException as e:
-            msg = "Failed to list workloads' deployments"
+            msg = f"Failed to list workloads' deployments{_detail_api_call_error(e)}"
             raise OperationError(msg) from e
 
         return [
@@ -1605,7 +1621,7 @@ class KubernetesDeployer(Deployer):
                 **logs_options,
             )
         except kubernetes.client.exceptions.ApiException as e:
-            msg = f"Failed to fetch logs for container {container.name} of workload {name}"
+            msg = f"Failed to fetch logs for container {container.name} of workload {name}{_detail_api_call_error(e)}"
             raise OperationError(msg) from e
         else:
             return output
@@ -1691,7 +1707,7 @@ class KubernetesDeployer(Deployer):
                 **exec_options,
             )
         except kubernetes.client.exceptions.ApiException as e:
-            msg = f"Failed to exec command in container {container.name} of workload {name}"
+            msg = f"Failed to exec command in container {container.name} of workload {name}{_detail_api_call_error(e)}"
             raise OperationError(msg) from e
         else:
             if not attach:
@@ -1906,3 +1922,30 @@ class KubernetesWorkloadExecStream(WorkloadExecStream):
         if not self.closed:
             return
         self._ws.close()
+
+
+def _detail_api_call_error(err: kubernetes.client.exceptions.ApiException) -> str:
+    """
+    Explain a Kubernetes API error in a concise way,
+    if the envs.GPUSTACK_RUNTIME_DEPLOY_API_CALL_ERROR_DETAIL is enabled.
+
+    Args:
+        err:
+            The Kubernetes API error.
+
+    Returns:
+        A concise explanation of the error.
+
+    """
+    if not envs.GPUSTACK_RUNTIME_DEPLOY_API_CALL_ERROR_DETAIL:
+        return ""
+
+    msg = ": Kubernetes Error"
+    if err.reason:
+        msg += f": {err.reason}"
+    elif err.body:
+        msg += f": {err.body}"
+    else:
+        msg += f": status code {err.status}"
+
+    return msg
